.. tripleo-common documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tripleo-common's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 2

   Introduction <readme>
   installation
   usage
   images
   tripleo-mistral
   contributing
   uploads
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

